##  Notification Channels
The following notification channels are available:
  * Email: Users receive notifications at the email addresses linked to their SAP LeanIX accounts. This is the primary notification channel. For more details, see [Configuring the E-Mail Channel](https://help.sap.com/docs/leanix/ea/configuring-e-mail-channel?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX provides flexible email notification options. You can customize the email template and use your own email server. Explore these settings to optimize the visibility and relevance of your email notifications.").
  * Microsoft Teams: If the integration with Microsoft Teams is configured for a workspace, users can receive notifications there. For more details, see [Configuring the Microsoft Teams Channel](https://help.sap.com/docs/leanix/ea/configuring-microsoft-teams-channel?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX provides notifications in Microsoft Teams with the Microsoft Teams integration.").


On the Channels tab of the Notifications Center page, you can navigate to a channel's configuration by clicking Edit Settings. You can enable or disable notifications from individual channels or both for all workspace users by using toggles. You can also mute notifications triggered by technical users, preventing alerts for actions related to events in your integrations.
![1936](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27531f047a441014a0db929d3f9bef07_LowRes.png)
Notifications Center in the Admin Area
